Bucket class

In terms of implementation, a Bucket is a resource. An Amazon S3 bucket name is globally unique, and the namespace is shared by all AWS accounts.

Constructors

Bucket(DateTime? creationDate, String name)
Bucket.fromXml(XmlElement xml)
factory

Properties

creationDate ↔ DateTime?
Date the bucket was created.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String
The name of the bucket.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override
toXml() → XmlNode

Operators

operator ==(Object other) → bool
The equality operator.
inherited