CopyConditions class

Constructors

CopyConditions()

Properties

hashCode → int
The hash code for this object.
no setterinherited
matchETag ↔ String?
getter/setter pair
matchETagExcept ↔ String?
getter/setter pair
modified ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unmodified ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setMatchETag(String etag) → void
setMatchETagExcept(String etag) → void
setModified(DateTime date) → void
setUnmodified(DateTime date) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited