Owner class

Container for the owner's display name and ID.

Constructors

Owner(String? displayName, String? iD)
Owner.fromXml(XmlElement? xml)

Properties

displayName ↔ String?
Container for the display name of the owner.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
iD ↔ String?
Container for the ID of the owner.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toXml() → XmlNode

Operators

operator ==(Object other) → bool
The equality operator.
inherited