PostPolicy class

Build PostPolicy object that can be signed by presignedPostPolicy

Constructors

PostPolicy()

Properties

formData → Map<String, String>
final
hashCode → int
The hash code for this object.
no setterinherited
policy → Map<String, dynamic>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setBucket(dynamic bucket) → void
set bucket name
setContentLengthRange(int min, int max) → void
set minimum/maximum length of what Content-Length can be.
setContentType(String type) → void
set Content-Type
setExpires(DateTime date) → void
set expiration date
setKey(String object) → void
set object name
setKeyStartsWith(String prefix) → void
set object name prefix, i.e policy allows any keys with this prefix
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited