TargetGrant class

Container for granting information.

Constructors

TargetGrant(Grantee? grantee, String? permission)
TargetGrant.fromXml(XmlElement? xml)

Properties

grantee ↔ Grantee?
Container for the person being granted permissions.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
permission ↔ String?
Logging permissions assigned to the Grantee for the bucket.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toXml() → XmlNode

Operators

operator ==(Object other) → bool
The equality operator.
inherited